@@ -18,13 +18,21 @@ sys.path.insert(0, os.path.abspath('./'))
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
-    'sphinx.ext.autodoc',
+    'sphinxcontrib.apidoc',
     'openstackdocstheme',
 ]
 
 # Add any paths that contain templates here, relative to this directory.
 # templates_path = ['_templates']
 
+# sphinxcontrib.apidoc options
+apidoc_module_dir = '../../mistralclient'
+apidoc_output_dir = 'api'
+apidoc_excluded_paths = [
+    'test',
+    'tests/*']
+apidoc_separate_modules = True
+
 # The suffix of source filenames.
 source_suffix = '.rst'
 
